<?php
/*
Plugin Name: WP Symposium Yes/No vote Widget
Plugin URI: http://www.wpsymposium.com
Description: Adds a WP Symposium Widget to display a Yes/No vote with chart (bar or pie). Requires a licence from http://www.jscharts.com to remove small JS Charts logo. Requires WP Symposium core plugin to be activated.
Version: 11.9.24
Author: WP Symposium
Author URI: http://www.wpsymposium.com
License: GPL3
*/

define('WPS_YESNO_VER', '11.9.24');

/*  Copyright 2010,2011  Simon Goodchild  (info@wpsymposium.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/** Add our function to the widgets_init hook. **/

add_action( 'widgets_init', 'symposium_load_widget_yesno_vote' );

function symposium_load_widget_yesno_vote() {
	register_widget( 'Symposium_vote_Widget' );
}


/** Symposium: Vote ************************************************************************* **/
class Symposium_vote_Widget extends WP_Widget {

	function Symposium_vote_Widget() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'widget_symposium_vote', 'description' => 'Allows members to vote on a YES/NO question.' );
		
		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'symposium_vote-widget' );
		
		/* Create the widget. */
		$this->WP_Widget( 'symposium_vote-widget', 'Symposium: '.__('Vote', 'wp-symposium-yesno'), $widget_ops, $control_ops );
	}
	
	// This is shown on the page
	function widget( $args, $instance ) {
		
		global $wpdb, $current_user;
		wp_get_current_user();
			
		extract( $args );

		// Get options
		$symposium_vote_question = apply_filters('widget_symposium_vote_question', $instance['symposium_vote_question'] );
		$symposium_vote_forum = apply_filters('widget_symposium_vote_forum', $instance['symposium_vote_forum'] );
		$symposium_vote_counts = apply_filters('widget_symposium_vote_counts', $instance['symposium_vote_counts'] );
		$symposium_vote_type = apply_filters('widget_symposium_vote_type', $instance['symposium_vote_type'] );
		$symposium_vote_key = apply_filters('widget_symposium_vote_key', $instance['symposium_vote_key'] );
		
		// Start widget
		echo $before_widget;
		echo $before_title . $symposium_vote_question . $after_title;
		
		// Content of widget

		echo '<div id="symposium_chartcontainer">Chart of results</div>';
		echo '<div id="symposium_chart_type" style="display:none">'.$symposium_vote_type.'</div>';
		echo '<div id="symposium_chart_counts" style="display:none">'.$symposium_vote_counts.'</div>';
		echo '<div id="symposium_chart_key" style="display:none">'.$symposium_vote_key.'</div>';

		// Store values
		$symposium_vote_yes = get_option("symposium_vote_yes");
		if ($symposium_vote_yes != false) {
			$symposium_vote_yes = (int) $symposium_vote_yes;
		} else {
		    add_option("symposium_vote_yes", 0);	    	   	
			$symposium_vote_yes = 0;
		}
		$symposium_vote_no = get_option("symposium_vote_no");
		if ($symposium_vote_no != false) {
			$symposium_vote_no = (int) $symposium_vote_no;
		} else {
		    add_option("symposium_vote_no", 0);	    	   	
			$symposium_vote_no = 0;
		}

		echo '<div id="symposium_chart_yes" style="display:none">'.$symposium_vote_yes.'</div>';
		echo '<div id="symposium_chart_no" style="display:none">'.$symposium_vote_no.'</div>';
			
		if (is_user_logged_in()) {
			
			$voted = $wpdb->get_var($wpdb->prepare("SELECT widget_voted FROM ".$wpdb->base_prefix."symposium_usermeta WHERE uid = ".$current_user->ID));
			if ($voted == "on") {
				
				echo "<p>";
				echo __('Thank you for voting', 'wp-symposium-yesno').".";
				if ($symposium_vote_forum != '') {
					echo "<br /><a href='".$symposium_vote_forum."'>".__('Discuss this on the forum', 'wp-symposium-yesno')."...</a>";
				}
				echo "</p>";

			} else {
			
			
				echo "<div id='symposium_vote_forum'>";
					echo "<p>".__('Your vote', 'wp-symposium-yesno').": ";
					echo "<a href='javascript:void(0)' title='yes' class='symposium_answer' value='".__("Yes", "wp-symposium-yesno")."'>".__("Yes", "wp-symposium-yesno")."</a> ".__('or', 'wp-symposium-yesno')." ";
					echo "<a href='javascript:void(0)' title='no' class='symposium_answer' value='".__("No", "wp-symposium-yesno")."'>".__("No", "wp-symposium-yesno")."</a>";
					if ($symposium_vote_forum != '') {
						echo "<br /><a href='".$symposium_vote_forum."'>".__('Discuss this on the forum', 'wp-symposium-yesno')."...</a>";
					}
					echo "</p>";
				echo "</div>";
				
				echo "<div id='symposium_vote_thankyou'>";
					echo "<p>".__("Thank you for voting, refresh the page for latest results", "wp-symposium-yesno");
					if ($symposium_vote_forum != '') {
						echo "<br /><a href='".$symposium_vote_forum."'>".__('Discuss this on the forum', 'wp-symposium-yesno')."...</a>";
					}
					echo "</p>";
				echo "</div>";
		
			}
			
		} else {
			
			echo "<p>".__("Log in to vote...", "wp-symposium-yesno")."</p>";
			
		}
				
		// End content
		
		echo $after_widget;
		// End widget
	}
	
	// This updates the stored values
	function update( $new_instance, $old_instance ) {

		global $wpdb;

		$instance = $old_instance;

		// Reset
		if (strip_tags( $new_instance['symposium_reset_votes'] ) == 'on' ) {
			update_option( "symposium_vote_yes", 0 );
			update_option( "symposium_vote_no", 0 );
			$wpdb->query( $wpdb->prepare("UPDATE ".$wpdb->base_prefix."symposium_usermeta SET widget_voted = ''") );
		}
		
		/* Strip tags (if needed) and update the widget settings. */
		$instance['symposium_vote_question'] = strip_tags( $new_instance['symposium_vote_question'] );
		$instance['symposium_vote_forum'] = strip_tags( $new_instance['symposium_vote_forum'] );
		$instance['symposium_vote_counts'] = strip_tags( $new_instance['symposium_vote_counts'] );
		$instance['symposium_vote_type'] = strip_tags( $new_instance['symposium_vote_type'] );
		$instance['symposium_vote_key'] = strip_tags( $new_instance['symposium_vote_key'] );
		return $instance;
	}
	
	// This is the admin form for the widget
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'symposium_vote_question' => __('A yes/no question...', 'wp-symposium-yesno'), 'symposium_vote_forum' => '' );
		$instance = wp_parse_args( (array) $instance, $defaults ); 

		$symposium_vote_yes = get_option("symposium_vote_yes");
		$symposium_vote_no = get_option("symposium_vote_no");

		$symposium_vote_key = get_option("symposium_vote_key");
				
		echo "<p><span style='font-weight:bold'>".__('Results so far', 'wp-symposium-yesno')."</span><br />";
		echo __("Yes", "wp-symposium-yesno").": ".$symposium_vote_yes."<br />";
		echo __("No", "wp-symposium-yesno").": ".$symposium_vote_no."</p>";
		?>		
		<p>
			<label 	for="<?php echo $this->get_field_id( 'symposium_vote_question' ); ?>"><?php echo __('Question', 'wp-symposium-yesno'); ?>:<br /></label>
			<input 	id="<?php echo $this->get_field_id( 'symposium_vote_question' ); ?>" 
					name="<?php echo $this->get_field_name( 'symposium_vote_question' ); ?>" 
					value="<?php echo $instance['symposium_vote_question']; ?>" />
		<br /><br />
			<label 	for="<?php echo $this->get_field_id( 'symposium_vote_forum' ); ?>"><?php echo __('Forum Link', 'wp-symposium-yesno'); ?>:<br /></label>
			<input 	id="<?php echo $this->get_field_id( 'symposium_vote_forum' ); ?>" 
					name="<?php echo $this->get_field_name( 'symposium_vote_forum' ); ?>" 
					value="<?php echo $instance['symposium_vote_forum']; ?>" />
		<br /><br />
			<label for="<?php echo $this->get_field_id( 'symposium_vote_counts' ); ?>"><?php echo __('Show values', 'wp-symposium-yesno'); ?>:</label>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'symposium_vote_counts' ); ?>" name="<?php echo $this->get_field_name( 'symposium_vote_counts' ); ?>"
			<?php if ($instance['symposium_vote_counts'] == 'on') { echo " CHECKED"; } ?>
			/>
			<br /><em>(if not, percentages shown)</em>
		<br /><br />
			<label for="<?php echo $this->get_field_id( 'symposium_vote_type' ); ?>"><?php echo __('Chart type', 'wp-symposium-yesno'); ?>:</label>
			<select type="checkbox" id="<?php echo $this->get_field_id( 'symposium_vote_type' ); ?>" name="<?php echo $this->get_field_name( 'symposium_vote_type' ); ?>">
				<option value="pie" <?php if ($instance['symposium_vote_type'] == 'pie') { echo " SELECTED"; } ?> >Pie</option>
				<option value="bar" <?php if ($instance['symposium_vote_type'] == 'bar') { echo " SELECTED"; } ?> >Bar</option>
			</select>
		<br /><br />
			<label for="<?php echo $this->get_field_id( 'symposium_reset_votes' ); ?>"><?php echo __('Reset votes?', 'wp-symposium-yesno'); ?>:</label>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'symposium_reset_votes' ); ?>" name="<?php echo $this->get_field_name( 'symposium_reset_votes' ); ?>" />
		<br /><br />
			<label 	for="<?php echo $this->get_field_id( 'symposium_vote_key' ); ?>"><?php echo __('Domain key', 'wp-symposium-yesno'); ?>:<br /></label>
			<input 	id="<?php echo $this->get_field_id( 'symposium_vote_key' ); ?>" 
					name="<?php echo $this->get_field_name( 'symposium_vote_key' ); ?>" 
					value="<?php echo $instance['symposium_vote_key']; ?>" />
			<br /><a href="http://www.wpswiki.com/index.php?title=Yes/No_Vote" target="_blank"><?php echo __('What is this?', 'wp-symposium-yesno'); ?></a>
		</p>
		<?php
	}

}

// Load CSS	    
wp_register_style('symposium_yesno-css', WP_PLUGIN_URL.'/wp-symposium-yesno/css/symposium_yesno.css');
wp_enqueue_style('symposium_yesno-css');

// Load JS
wp_register_script('symposium_yesno', WP_PLUGIN_URL . '/wp-symposium-yesno/js/symposium-yesno.js');
wp_enqueue_script('jquery-symposium_yesno', WP_PLUGIN_URL.'/wp-symposium-yesno/js/symposium-yesno.js', array('jquery'));

// JS Chart
wp_register_script('symposium_jsChart', WP_PLUGIN_URL . '/wp-symposium-yesno/js/jscharts.js');
wp_enqueue_script('symposium_jsChart');

// ----------------------------------------------------------------------------------------------------------------------------------------------------------

// Language files
if ( function_exists('load_plugin_textdomain') ) {
	load_plugin_textdomain( 'wp-symposium-yesno', false, dirname( plugin_basename( __FILE__ ) ) . '/lang' );		
}

?>
